@@ -43,7 +43,7 @@ def download_file(key):
     with open(metadata_path) as f:
         metadata = json.load(f)
         content_type = metadata.get("Content-Type", 'application/octet-stream')
-    with open(file_path, 'r') as f:
+    with open(file_path, 'rb') as f:
         response = HttpResponse(f.read(), content_type=content_type)
 
     file_name = os.path.basename(os.path.dirname(file_path))
@@ -105,14 +105,17 @@ def safe_save(path, content):
     """
     dir_path = os.path.abspath(os.path.dirname(path))
     if not dir_path.startswith(get_bucket_path()):
-        raise exceptions.FileUploadRequestError(u"Uploaded file name not allowed: '%s'" % path)
+        raise exceptions.FileUploadRequestError("Uploaded file name not allowed: '%s'" % path)
     root_directory = get_root_directory_path()
     if not os.path.exists(root_directory):
-        raise exceptions.FileUploadInternalError(u"File upload root directory does not exist: %s" % root_directory)
+        raise exceptions.FileUploadInternalError("File upload root directory does not exist: %s" % root_directory)
     if not os.path.exists(dir_path):
         os.makedirs(dir_path)
-    with open(path, 'w') as f:
-        f.write(content.decode('utf-8') if isinstance(content, bytes) else content)
+    mode = "w"
+    if isinstance(content, bytes):
+        mode = "wb"
+    with open(path, mode) as f:
+        f.write(content)
 
 
 def safe_remove(path):
